#version 150

#moj_import <purple_border_gui/util_functions.glsl>
#moj_import <purple_border_gui/item_selection_bitmap.glsl>
#moj_import <purple_border_gui/other_colours.glsl>

in vec4 vertexColor;
in vec4 gradientColor;
// resolution of gradient or bitmap depending on bgRenderMode
// r = vertical resolution
// g = horizontal resolution
in vec4 gradientResolution;
// 1 = crafting table text box
// 2 = slot highlight
in float renderSlotHighlight;
in vec3 cornerPos1;
in vec3 cornerPos2;
in vec3 cornerPos3;
in vec3 pos;

uniform vec4 ColorModulator;
uniform mat4 ProjMat;

out vec4 fragColor;

void main() {
    vec4 color = vertexColor;

    vec2 cornerPx1 = cornerPos1.xy / cornerPos1.z;
    vec2 cornerPx2 = cornerPos2.xy / cornerPos2.z;
    vec2 cornerPx3 = cornerPos3.xy / cornerPos3.z;
    vec2 minPos = min(cornerPx1, min(cornerPx2, cornerPx3));
    vec2 maxPos = max(cornerPx1, max(cornerPx2, cornerPx3));

    float quadHeight = int( round( abs( (minPos.y - maxPos.y) ) ) );
    float quadWidth = int( round( abs( (minPos.x - maxPos.x) ) ) );

    if (pos.z == 0 && ProjMat[3][0] == -1) {
        // selected world/server/resourcepack background
        if( 
            (quadWidth == 268 || quadWidth == 303 || quadWidth == 298 || quadWidth == 191 || quadWidth == 198) && 
            quadHeight == 34 && 
            roughlyEquals( vertexColor, vec4(0,0,0,1) ) 
        ) {
            vec4 gradientAmount = getGradientWithResolution(gradientColor, vec4(quadHeight, quadWidth, 0, 0)).yxzw;

            vec3 background = SELECTED_WORLD_BACKGROUND;
            vec3 lightAccent = SELECTED_WORLD_BACKGROUND_ACCENT;

            color.rgb = mix(lightAccent, background, clamp(gradientAmount.y * 7.5, 0, 1) );
        }
        // selected world/server/resourcepack border
        else if( 
            (quadWidth == 270 || quadWidth == 305 || quadWidth == 300 || quadWidth == 200 || quadWidth == 193) && 
            quadHeight == 36 && 
            (roughlyEquals( vertexColor, vec4(1) ) || roughlyEquals( vertexColor, vec4(0.50196, 0.50196, 0.50196,1) ) )
        ) {
            color.rgb = SELECTED_WORLD_BACKGROUND_BORDER;
        }

        // incompatible resourcepack
        else if (
            (quadWidth == 191 || quadWidth == 198) &&
            quadHeight == 34 &&
            roughlyEquals(vertexColor, vec4(0.466667, 0.0, 0.0, 1.0))
        ) {
            color.rgb = INCOMPATIBLE_RESOURCEPACK;
        }
    }

    // advancement hover background
    if(
        quadWidth == 234 && 
        quadHeight == 113 && 
        vertexColor.a <= 0.29804 && 
        roughlyEquals(vertexColor.rgb, vec3(0.0,0.0,0.0))
    ) {
        color.rgb = ADVANCEMENT_HOVERED_BACKGROUND;
        color.a = vertexColor.a * 1.7;
    }
    
    // slot highlight
    if(renderSlotHighlight > 0){
        vec4 gradientColorUV = getGradientWithResolution(gradientColor, gradientResolution) * gradientResolution; // coordinates for bitmap texture
        int x = int(gradientColorUV.g);
        int y = int(gradientColorUV.r);

        for(int i = 0; i < y; i++){
            x += int(gradientResolution.x);
        }

        if(renderSlotHighlight > 2.9) {
            color = slotRightClickDraggingColors[slotRightClickDraggingBitmap[x]];
        }
    }

    if (color.a == 0.0) {
        discard;
    }

    fragColor = color * ColorModulator;
}
